# Changelog

All notable changes to **Pipecat MCP Server** will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.0.2] - 2026-01-26

### Fixed

- Fixed an issue that would cause the Pipecat agent to not load if the optional
  `daily` dependency was not installed.

- Added missing support for `telnyx`, `plivo` and `exotel` telephony providers.

## [0.0.1] - 2026-01-26

Initial public release.
